rm(list=ls())
#============================
#Annual Analysis for USA Data 
#============================
install.packages("LongRunVol_1.0.tar.gz", repos = NULL, type="source")
install.packages("MCMCpack")

source("ALLfunctions.R")
source("ALLfunctions_TV.R")
library(MCMCpack)
library(LongRunVol)

#############################
## Load Data                #
#############################
data(YearlyData)

R = YearlyData$R.y
n = length(R)
x = as.matrix(YearlyData[,2:4])
x0 = apply(x,2,mean)
r=R

hoz=50  # horizon for long run vol

## Calculating unconditional (conventional wisdom) measure
##########################################################
CW = sd(R)
k=1:(hoz-1)
for(j in 1:length(k)){
lixo = rep(0,n-k[j])
for(i in 1:(n-k[j])){
	
	lixo[i] = sum(R[i:(i+k[j])])
	
	}
	
CW = c(CW,sqrt(var(lixo)/(k[j]+1)))
}

CW = sd(R)
k=1:(hoz-1)
for(j in 1:length(k)){
lixo = rep(0,n-k[j])
for(i in 1:(n-k[j])){
	
	lixo[i] = sum(R[i:(i+k[j])])
	
	}
	
CW = c(CW,sqrt(var(lixo)/(k[j]+1)))
}
country="USA Annual: 1800-2015"

## IID model:
########################

iid = getiid(R,10000,50)


## Weak Prior setting:
#######################
strong=0

## Run Code:
source("LongRunSource.R")

LR = NULL
LR = cbind(LR,exp(LongRunPastor)-1)


## Strong Prior setting:
#######################
strong=1
#######################

## Run Code:
source("LongRunSource.R")
LR = cbind(LR,exp(LongRunPastor)-1)


## TV Sigma setting:
#######################
source("LongRunSourceTV.R")
LR = cbind(LR,exp(LongRunPastor)-1)


## Figure 4 of the paper
par(mfrow=c(1,1)) 
plot(smooth((LR[,3])*100),type='l',lwd=2,col=1,lty=1,ylab="Vol per Period (% per year)",xlab="Horizon (years)",ylim=c(7,24),main=country)
lines((exp(CW)-1)*100,lwd=3,col=1,lty=2)
lines(LR[,1]*100,lwd=2,col=1)
lines(LR[,2]*100,lwd=2,col=1)
lines(LR[,6]*100,lwd=2,col=1)
segments(1,100*(exp(iid[1])-1),hoz,100*(exp(iid[hoz])-1),lwd=2,col=1)

text(45,(exp(iid[hoz])-1)*100 - 0.7,"iid",col=1,cex=1.2)
text(45,LR[45,1]*100 - 0.5,"weak prior",col=1,cex=1.2)
text(43,LR[43,3]*100 - 0.6,"time-varying Sigma",col=1,cex=1.2)
text(45,LR[45,2]*100 - 0.5,"strong prior",col=1,cex=1.2)
text(45,(exp(CW[45])-1)*100 + 0.7,"unconditional",col=1,cex=1.2)









